=======================
 Issues and Change Log
=======================

Here__ is the exported HTML output from the :kbd:`export html` command.

__ _static/index.html

Here's the release history of |PD|, built using the :kbd:`changelog`
command:

.. literalinclude:: ../NEWS
   :language: ditz
